#!/bin/sh
# doit.sh
# version 2.0.2  08nov2005
# Written by:   Jeff Pitblado
# Description:  UNIX shell script to latex a Stata Press book

# The following definitions may be modified, but be careful.
# For example, you can change main to book (emain to ebook).
MAIN=main		# main driver
EMAIN=emain		# electronic version of main driver

##############################################################################
# DO NOT EDIT BEYOND THIS POINT (unless you know what you are doing)
self=`basename $0`

# Subroutines ###############################################################

usage () {
	cat << EOF 1>&2
usage:  $self [option(s)]

Run LaTeX, BibTeX, and Makeindex to create a Stata Press book.
$self assumes the driver files is ${MAIN}.tex.

Options:
	h		Display this information and quit; the default
        e		use ${EMAIN}.tex instead of ${MAIN}.tex

	clean		start clean, remove all auxiliary files

	bib 		run BibTeX
	idx 		run Makeindex
	dvi		run LaTeX to produce a dvi file
	ps		run dvips, but will check for the dvi file first
	pdf		run ps2pdf, but will check for ps file first

	all		shortcut for -clean bib idx dvi ps-

EOF
	exit 1
}

RUNTEX () {
	if ! latex --interaction batchmode $MAIN
	then
		echo
		echo "$self: error occured with (latex $MAIN)"
		echo "$self: exiting now"
		exit 1
	fi
}

# Parsing ###################################################################

CLEAN=0
BIB=0
IDX=0
TEX=0
DVIPS=0
PS2PDF=0
ALL=0
while [ ! -z "$1" ]
do 
	case $1 in
	h|-h|--help)
		usage
		;;
	e)
		MAIN=$EMAIN
		shift
		;;
	clean)
		CLEAN=1
		TEX=1
		shift
		;;
	bib|b|-b|--bibtex)
		BIB=1
		shift
		;;
	idx|i|m|-m|--makeindex)
		IDX=1
		shift
		;;
	dvi|latex)
		TEX=1
		shift
		;;
	ps|--dvips)
		DVIPS=1
		shift
		;;
	pdf|--ps2pdf)
		PS2PDF=1
		shift
		;;
	all)
		ALL=1
		shift
		;;
	*)
		echo "$self: unknown option: $1" 1>&2
		echo 1>&2
		usage
		;;
	esac
done

if [ "${CLEAN}${BIB}${IDX}${TEX}${DVIPS}${PS2PDF}${ALL}" = "0000000" ]
then
	usage
fi

# The following must appear after the above loop; $MAIN may change from the
# default if the -e- option is specified:

# DVI to PostScript conversion
DVIPSCMD="dvips -Ppdf -G0 -o ${MAIN}.ps ${MAIN}.dvi"
# PostScript to PDF conversion
PS2PDFCMD="ps2pdf ${MAIN}.ps ${MAIN}.pdf"

# Option dependencies #######################################################

if [ "$ALL" = "1" ]
then
	CLEAN=1
	BIB=1
	IDX=1
	TEX=1
	DVIPS=1
fi
if [ "$PS2PDF" = "1" -a "$DVIPS" = "0" ]
then
	if [ ! -f $MAIN.ps ]
	then
		DVIPS=1
	fi
fi
if [ "$DVIPS" = "1" -a "$TEX" = "0" ]
then
	if [ ! -f $MAIN.dvi ]
	then
		TEX=1
	fi
fi
if [ "$BIB" = "1" -o "$IDX" = "1" ]
then
	TEX=1
fi
if [ "$TEX" = "1" ]
then
	if [ ! -f $MAIN.tex ]
	then
		echo "$self:  $MAIN.tex:  no such file"
		exit 1
	fi
fi
if [ "$CLEAN" = "1" ]
then
	echo
	echo "$self:  cleaning auxiliary files"
	rm -f *.aux *.lof *.lot *.toc *.mtc*
	rm -f *.ind
fi

# Document production #######################################################

rm -f bibtex.log makeindex.log
if [ "$TEX" = "1" ]
then
	# initial run
	RUNTEX
fi

# Run bibtex on $MAIN.aux, save the output to a log file.
if [ "$BIB" = "1" ]
then
	echo "Running bibtex ..."
	bibtex ${MAIN} > bibtex.log

	# place citations and references
	RUNTEX
else
	echo "bibtex was not run" > bibtex.log
fi

# make index entries for last latex run
if [ "$IDX" = "1" ]
then
	echo "Running makeindex ..."
	makeindex -s dot.ist author.idx > makeindex.log 2>&1
	makeindex -s dot.ist subject.idx >> makeindex.log 2>&1

	# last run
	RUNTEX
else
	echo "makeindex was not run" > makeindex.log
fi

OUTPUT="$MAIN.dvi"
if [ "$DVIPS" = "1" ]
then
	echo
	echo "$self:  creating $MAIN.ps"
	$DVIPSCMD
	OUTPUT="$MAIN.ps"
fi
if [ "$PS2PDF" = "1" ]
then
	echo
	echo "$self:  creating $MAIN.pdf"
	$PS2PDFCMD
	OUTPUT="$MAIN.pdf"
fi

echo
echo "$self:  see bibtex.log for errors in references"
echo "$self:  see makeindex.log for errors in indices"
echo "$self:  ready for viewing: $OUTPUT"

exit
##############################################################################
